@@ -3,11 +3,12 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0820';
+our $VERSION = '0.0821';
 
 use Moo;
 use strictures 2;
 use MIDI::Simple ();
+use MIDI::Util qw(reverse_dump);
 use Math::Random::Discrete ();
 use List::Util qw(min);
 use namespace::clean;
@@ -115,6 +116,12 @@ has remainder => (
 );
 
 
+has abbreviation => (
+    is      => 'ro',
+    default => sub { return 1 },
+);
+
+
 has verbose => (
     is      => 'ro',
     default => sub { return 0 },
@@ -165,8 +172,16 @@ sub motif {
         if (sprintf( $format, $diff ) < sprintf( $format, $self->_min_size )) {
             warn "WARNING: Leftover duration: $diff\n"
                 if $self->verbose;
-            push @$motif, 'd' . sprintf('%.0f', TICKS * $diff)
-                if $self->remainder && sprintf($format, TICKS * $diff) > 0;
+            my $tick_diff = TICKS * $diff;
+            my $dura = 'd' . sprintf('%.0f', $tick_diff);
+            if ($self->abbreviation) {
+                my $length = reverse_dump('length');
+                my %length = map { TICKS * $_ => $length->{$_} } keys %$length;
+                $dura = $length{$tick_diff}
+                    if exists $length{$tick_diff};
+            }
+            push @$motif, $dura
+                if $self->remainder && sprintf($format, $tick_diff) > 0;
             last;
         }
 
@@ -233,7 +248,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0820
+version 0.0821
 
 =head1 SYNOPSIS
 
@@ -342,6 +357,16 @@ Append any remaining duration ticks to the end of the motif.
 
 Default: C<1> "Yes. Make it so."
 
+=head2 abbreviation
+
+  $abbreviation = $mdp->abbreviation;
+
+Any remaining duration is checked against the L<MIDI::Simple::Length>
+hash to see if it is included. If so, use that abbreviation, instead
+of a C<d> value.
+
+Default: C<1> "Yes. Make it so."
+
 =head2 verbose
 
   $verbose = $mdp->verbose;
